==> SV1000-Linux.SV1.2.109.tar.gz: SpliceCom/WebManager/admin/managephones/load.php <==
<?php
	$selectedName 		= (isset($_REQUEST['selectedName']) && strlen($_REQUEST['selectedName']) > 1) ? $_REQUEST['selectedName'] : NULL;
	$selectedGuid 		= (isset($_REQUEST['selectedGuid']) && strlen($_REQUEST['selectedGuid']) > 1) ? $_REQUEST['selectedGuid'] : NULL;
	$selectedSystemName = (isset($_REQUEST['selectedSystemName']) && strlen($_REQUEST['selectedSystemName']) > 1) ? $_REQUEST['selectedSystemName'] : NULL;
	$selectedSystemGuid = (isset($_REQUEST['selectedSystemGuid']) && strlen($_REQUEST['selectedSystemGuid']) > 1) ? $_REQUEST['selectedSystemGuid'] : NULL;
	$typeofphone 		= (isset($_REQUEST['typeofphone']) && strlen($_REQUEST['typeofphone']) > 1) ? $_REQUEST['typeofphone'] : NULL;

	$sr = ldap_read($ds,"guid=$selectedGuid, cn=modules","objectclass=Phone",array('dn','cn','description','productversion')); 
	$info = ldap_get_entries($ds,$sr);
	$dn = $info[0]['dn'];
	$phoneName = $info[0]['cn'][0];
	$description = $info[0]['description'][0];
	$productversion = $info[0]['productversion'][0];
	$sipType = '';
	
	
	$pnpversion = $pnpmodel = $pnpvendor = $stunaddr = $stunport = $usestun = '';

if (strpos($typeofphone, 'PCS') !== false) {
	$phoneNameText = 'Splicecom PCS Phone Name'; $phoneNameSpan = 'NAME ASSIGNED TO SPLICECOM PCS IP PHONE'; $phoneNameState = ''; $selectedType = '2';
	$sr = ldap_list($ds,"$dn","objectclass=*",array('serialnumber','partnerlogincode','update','remotepstn')); 
	$info = ldap_get_entries($ds,$sr);
	$pcsSerial = (isset($info[0]['serialnumber'][0]) && strlen($info[0]['serialnumber'][0]) >= 1) ? $info[0]['serialnumber'][0] : NULL;
	$pcsPlc = (isset($info[0]['partnerlogincode'][0]) && strlen($info[0]['partnerlogincode'][0]) >= 1) ? $info[0]['partnerlogincode'][0] : NULL;
	$pcsUpgrade = (isset($info[0]['update'][0]) && strlen($info[0]['update'][0]) >= 1) ? $info[0]['update'][0] : NULL;
	$pcsExtnAnyWhere = (isset($info[0]['remotepstn'][0]) && strlen($info[0]['remotepstn'][0]) >= 1) ? $info[0]['remotepstn'][0] : NULL;
	
		
} else if (strpos($typeofphone, 'Analogue') !== false) {
	$phoneNameText = 'Splicecom Analogue Port Name'; $phoneNameSpan = 'NAME ASSIGNED TO ANALOGUE PORT'; $phoneNameState = 'readonly'; $selectedType = '1';
	$sr = ldap_list($ds,"$dn","objectclass=*",array('callerdisplaytype','callerdisplaylen','partnerlogincode','suppressdtmf','remotepstn')); 
	$info = ldap_get_entries($ds,$sr);
	$potCallerDisplayType = (isset($info[0]['callerdisplaytype'][0]) && strlen($info[0]['callerdisplaytype'][0]) >= 1) ? $info[0]['callerdisplaytype'][0] : NULL;
	$potCallerDisplayLength = (isset($info[0]['callerdisplaylen'][0]) && strlen($info[0]['callerdisplaylen'][0]) >= 1) ? $info[0]['callerdisplaylen'][0] : NULL;
	$potPlc = (isset($info[0]['partnerlogincode'][0]) && strlen($info[0]['partnerlogincode'][0]) >= 1) ? $info[0]['partnerlogincode'][0] : NULL;
	$potsDTMF = (isset($info[0]['suppressdtmf'][0]) && strlen($info[0]['suppressdtmf'][0]) >= 1) ? $info[0]['suppressdtmf'][0] : NULL;
	$potExtnAnyWhere = (isset($info[0]['remotepstn'][0]) && strlen($info[0]['remotepstn'][0]) >= 1) ? $info[0]['remotepstn'][0] : NULL;
	
} else if (strpos($typeofphone, 'SIP') !== false) {

	$sipType = (substr($phoneName, 0, 3) === 'SIP') ? 'Yealink' : 'Generic';
	$phoneNameText = 'SIP Device Name'; $phoneNameSpan = 'NAME ASSIGNED TO SIP DEVICE'; $phoneNameState = ''; $selectedType = '3';
	$sr = ldap_list($ds,"$dn","objectclass=*",array('ipaddress','serialnumber','pnpversion','pnpmodel','pnpvendor','stunaddr','stunport','usestun','siplicense'));
	$info = ldap_get_entries($ds,$sr);
	$phoneIPAddress = (isset($info[0]['ipaddress'][0]) && strlen($info[0]['ipaddress'][0]) >= 1) ? $info[0]['ipaddress'][0] : NULL;
	$sipMACAddress = (isset($info[0]['serialnumber'][0]) && strlen($info[0]['serialnumber'][0]) >= 1) ? $info[0]['serialnumber'][0] : NULL;
	$pnpversion = (isset($info[0]['pnpversion'][0]) && strlen($info[0]['pnpversion'][0]) >= 1) ? $info[0]['pnpversion'][0] : NULL;
	$pnpmodel = (isset($info[0]['pnpmodel'][0]) && strlen($info[0]['pnpmodel'][0]) >= 1) ? $info[0]['pnpmodel'][0] : NULL;
	$pnpvendor = (isset($info[0]['pnpvendor'][0]) && strlen($info[0]['pnpvendor'][0]) >= 1) ? $info[0]['pnpvendor'][0] : NULL;
	$stunaddr = (isset($info[0]['stunaddr'][0]) && strlen($info[0]['stunaddr'][0]) >= 1) ? $info[0]['stunaddr'][0] : NULL;
	$stunport = (isset($info[0]['stunport'][0]) && strlen($info[0]['stunport'][0]) >= 1) ? $info[0]['stunport'][0] : NULL;
	$usestun = (isset($info[0]['usestun'][0]) && strlen($info[0]['usestun'][0]) >= 1) ? $info[0]['usestun'][0] : NULL;
	$siplicense = (isset($info[0]['siplicense'][0]) && strlen($info[0]['siplicense'][0]) >= 1) ? $info[0]['siplicense'][0] : NULL;
}



?>

==> SV1000-Linux.SV1.3.117.tar.gz: SpliceCom/WebManager/admin/managephones/load.php <==
<?php
	$selectedName 		= (isset($_REQUEST['selectedName']) && strlen($_REQUEST['selectedName']) > 1) ? $_REQUEST['selectedName'] : NULL;
	$selectedGuid 		= (isset($_REQUEST['selectedGuid']) && strlen($_REQUEST['selectedGuid']) > 1) ? $_REQUEST['selectedGuid'] : NULL;
	$selectedSystemName = (isset($_REQUEST['selectedSystemName']) && strlen($_REQUEST['selectedSystemName']) > 1) ? $_REQUEST['selectedSystemName'] : NULL;
	$selectedSystemGuid = (isset($_REQUEST['selectedSystemGuid']) && strlen($_REQUEST['selectedSystemGuid']) > 1) ? $_REQUEST['selectedSystemGuid'] : NULL;
	$typeofphone 		= (isset($_REQUEST['typeofphone']) && strlen($_REQUEST['typeofphone']) > 1) ? $_REQUEST['typeofphone'] : NULL;

	$sr = ldap_read($ds,"guid=$selectedGuid","(objectclass=Phone)",array('dn','cn','description','productversion','initialuser')); 
	$info = ldap_get_entries($ds,$sr);
	$dn = $info[0]['dn'];
	$phoneName = $info[0]['cn'][0];
	$description = $info[0]['description'][0];
	$productversion = $info[0]['productversion'][0];
	$sipType = '';
	$initialuser = (isset($info[0]['initialuser'][0]) && strlen($info[0]['initialuser'][0]) >= 1) ? $info[0]['initialuser'][0] : '';
	
	
	$pnpversion = $pnpmodel = $pnpvendor = $stunaddr = $stunport = $usestun = '';

if (strpos($typeofphone, 'PCS') !== false) {
	$phoneNameText = 'Splicecom PCS Phone Name'; $phoneNameSpan = 'NAME ASSIGNED TO SPLICECOM PCS IP PHONE'; $phoneNameState = ''; $selectedType = '2';
	$sr = ldap_list($ds,"$dn","(objectclass=*)",array('serialnumber','partnerlogincode','update','remotepstn','initialuser')); 
	$info = ldap_get_entries($ds,$sr);
	$pcsSerial = (isset($info[0]['serialnumber'][0]) && strlen($info[0]['serialnumber'][0]) >= 1) ? $info[0]['serialnumber'][0] : NULL;
	$pcsPlc = (isset($info[0]['partnerlogincode'][0]) && strlen($info[0]['partnerlogincode'][0]) >= 1) ? $info[0]['partnerlogincode'][0] : NULL;
	$pcsUpgrade = (isset($info[0]['update'][0]) && strlen($info[0]['update'][0]) >= 1) ? $info[0]['update'][0] : NULL;
	$pcsExtnAnyWhere = (isset($info[0]['remotepstn'][0]) && strlen($info[0]['remotepstn'][0]) >= 1) ? $info[0]['remotepstn'][0] : NULL;
	
		
} else if (strpos($typeofphone, 'Analogue') !== false) {
	$phoneNameText = 'Splicecom Analogue Port Name'; $phoneNameSpan = 'NAME ASSIGNED TO ANALOGUE PORT'; $phoneNameState = 'readonly'; $selectedType = '1';
	$sr = ldap_list($ds,"$dn","(objectclass=*)",array('callerdisplaytype','callerdisplaylen','partnerlogincode','suppressdtmf','remotepstn')); 
	$info = ldap_get_entries($ds,$sr);
	$potCallerDisplayType = (isset($info[0]['callerdisplaytype'][0]) && strlen($info[0]['callerdisplaytype'][0]) >= 1) ? $info[0]['callerdisplaytype'][0] : NULL;
	$potCallerDisplayLength = (isset($info[0]['callerdisplaylen'][0]) && strlen($info[0]['callerdisplaylen'][0]) >= 1) ? $info[0]['callerdisplaylen'][0] : NULL;
	$potPlc = (isset($info[0]['partnerlogincode'][0]) && strlen($info[0]['partnerlogincode'][0]) >= 1) ? $info[0]['partnerlogincode'][0] : NULL;
	$potsDTMF = (isset($info[0]['suppressdtmf'][0]) && strlen($info[0]['suppressdtmf'][0]) >= 1) ? $info[0]['suppressdtmf'][0] : NULL;
	$potExtnAnyWhere = (isset($info[0]['remotepstn'][0]) && strlen($info[0]['remotepstn'][0]) >= 1) ? $info[0]['remotepstn'][0] : NULL;
	
} else if (strpos($typeofphone, 'SIP') !== false) {

	$sipType = (substr($phoneName, 0, 3) === 'SIP') ? 'Yealink' : 'Generic';
	$phoneNameText = 'SIP Device Name'; $phoneNameSpan = 'NAME ASSIGNED TO SIP DEVICE'; $phoneNameState = ''; $selectedType = '3';
	$sr = ldap_list($ds,"$dn","(objectclass=*)",array('ipaddress','serialnumber','pnpversion','pnpmodel','pnpvendor','stunaddr','stunport','usestun','siplicense','initialuser'));
	$info = ldap_get_entries($ds,$sr);
	$phoneIPAddress = (isset($info[0]['ipaddress'][0]) && strlen($info[0]['ipaddress'][0]) >= 1) ? $info[0]['ipaddress'][0] : NULL;
	$sipMACAddress = (isset($info[0]['serialnumber'][0]) && strlen($info[0]['serialnumber'][0]) >= 1) ? $info[0]['serialnumber'][0] : NULL;
	$pnpversion = (isset($info[0]['pnpversion'][0]) && strlen($info[0]['pnpversion'][0]) >= 1) ? $info[0]['pnpversion'][0] : NULL;
	$pnpmodel = (isset($info[0]['pnpmodel'][0]) && strlen($info[0]['pnpmodel'][0]) >= 1) ? $info[0]['pnpmodel'][0] : NULL;
	$pnpvendor = (isset($info[0]['pnpvendor'][0]) && strlen($info[0]['pnpvendor'][0]) >= 1) ? $info[0]['pnpvendor'][0] : NULL;
	$stunaddr = (isset($info[0]['stunaddr'][0]) && strlen($info[0]['stunaddr'][0]) >= 1) ? $info[0]['stunaddr'][0] : NULL;
	$stunport = (isset($info[0]['stunport'][0]) && strlen($info[0]['stunport'][0]) >= 1) ? $info[0]['stunport'][0] : NULL;
	$usestun = (isset($info[0]['usestun'][0]) && strlen($info[0]['usestun'][0]) >= 1) ? $info[0]['usestun'][0] : NULL;
	$siplicense = (isset($info[0]['siplicense'][0]) && strlen($info[0]['siplicense'][0]) >= 1) ? $info[0]['siplicense'][0] : NULL;
}



?>
